@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ ReadServerSieveConfigJob::ReadServerSieveConfigJob(QObject *parent)
     connect(this, &ReadServerSieveConfigJob::loadNextConfig, this, &ReadServerSieveConfigJob::slotReadNextConfig);
 }
 
-ReadServerSieveConfigJob::~ReadServerSieveConfigJob()
-{
-}
+ReadServerSieveConfigJob::~ReadServerSieveConfigJob() = default;
 
 void ReadServerSieveConfigJob::loadSettings(const QString &conf)
 {
