@@ -89,12 +89,16 @@ Q_SIGNALS:
     void copyAvailable(bool);
     void sieveEditorTabCurrentChanged();
 
+protected:
+    Q_REQUIRED_RESULT bool event(QEvent *e) override;
+
 private:
     void slotCreateScriptPage(const KSieveUi::ManageSieveWidget::ScriptInfo &info, bool isNewScript);
     void slotScriptDeleted(const QUrl &url);
     void slotScriptRenamed(const QUrl &oldUrl, const QUrl &newUrl);
     void slotScriptModified(bool modified, SieveEditorPageWidget *page);
     void slotGeneralPaletteChanged();
+    void updatePaletteColor();
     void slotTabCloseRequested(int index);
     void slotTabRemoveAllExclude(int index);
     void slotTabCloseAllRequested();
